# Orbeez

Code/Astro 2025 group 10

 GIF animation generator for exoplanetary system orbits. Detailed documentation (and soon installation instructions and tutorials) can be found [here](https://orbeez.readthedocs.io/en/latest/).



[![A rectangular badge, half black half purple containing the text made at Code Astro](https://img.shields.io/badge/Made%20at-Code/Astro-blueviolet.svg)](https://semaphorep.github.io/codeastro/)
![PyPI - Version](https://img.shields.io/pypi/v/Orbeez?color=green)
[![CI Testing](https://github.com/esofov/Orbeez/actions/workflows/python-app.yml/badge.svg)](https://github.com/esofov/Orbeez/actions/workflows/python-app.yml)
[![Documentation Status](https://readthedocs.org/projects/orbeez/badge/?version=latest)](https://orbeez.readthedocs.io/en/latest/?badge=latest)

[![DOI](https://zenodo.org/badge/1032001027.svg)](https://doi.org/10.5281/zenodo.16754434)
[![License](https://img.shields.io/github/license/esofov/Orbeez?color=blue)](https://opensource.org/license/mit)


